@@ -23,6 +23,8 @@
   #:export (exact-truncate
             exact-floor
             call-with-clip-rect
+            create-rgba-surface
+            create-rgba-square
             rotate-square
             rectangle-closure
             rectangle<-geometry-string
@@ -33,6 +35,7 @@
             ignore-all-event-types-except
             fader/3p
             toroidal-panner/3p)
+  #:use-module ((sdl gfx) #:prefix GFX:)
   #:use-module ((sdl sdl) #:prefix SDL:))
 
 ;; Return the exact truncation (rounding to zero) of @var{number}.
@@ -66,23 +69,70 @@
     (thunk)
     (SDL:set-clip-rect! s orig)))
 
+;; Return a new 32bpp RGBA surface with dimensions @var{w} by @var{h} pixels.
+;; The surface has flag @code{src-alpha} set.
+;; The masks are as follows:
+;;
+;; @example
+;; red     #x000000FF
+;; green   #x0000FF00
+;; blue    #x00FF0000
+;; alpha   #xFF000000
+;; @end example
+;;
+(define (create-rgba-surface w h)
+  (SDL:create-rgb-surface '(src-alpha)
+                          w h
+                          32            ; depth
+                          #x000000FF
+                          #x0000FF00
+                          #x00FF0000
+                          #xFF000000))
+
+;; Return a new 32bpp RGBA square surface with @var{edge-len} sides.
+;; (Both width and height are @var{edge-len}, an integer.)
+;;
+(define (create-rgba-square edge-len)
+  (create-rgba-surface edge-len edge-len))
+
 ;; Return a new surface made by rotating @var{square} by @var{angle} degrees.
 ;; The square retains its original size.
+;; If the new surface has flag @code{src-alpha} set, use
+;; @code{(sdl gfx) blit-rgba}, otherwise @code{(sdl sdl) blit-surface},
+;; for the resizing blit.
 ;;
-;;-args: (2 0 0 square angle)
+;; Optional arg @var{mksquare} is a procedure of one arg that creates a
+;; square surface.  If unspecified, use @code{create-rgba-square}.
 ;;
-(define (rotate-square src angle)
-  (let* ((width (SDL:surface:w src))
-         (height (SDL:surface:h src))
-         (rotated (SDL:roto-zoom-surface src (- angle 90) 1.0 #t))
-         (new-width (SDL:surface:w rotated))
-         (new-height (SDL:surface:h rotated))
-         (width-offset (ash (- new-width width) -1))
-         (height-offset (ash (- new-height height) -1))
-         (src-rect (SDL:make-rect width-offset height-offset width height))
-         (dst (SDL:make-surface width height))
-         (dst-rect (SDL:make-rect 0 0 width height)))
-    (SDL:blit-surface rotated src-rect dst dst-rect)
+;; See @code{roto-zoom-surface} for interpretation of @var{angle}.
+;;
+;;-args: (- 1 0)
+;;
+(define (rotate-square square angle . mksquare)
+  (define edge-len (SDL:surface:w square))
+  (define rotated  (GFX:roto-zoom-surface square angle 1.0 #t))
+  (define create-square (if (pair? mksquare)
+                            (car mksquare)
+                            create-rgba-square))
+
+  (define (mkrect x y)
+    (SDL:make-rect x y
+                   edge-len
+                   edge-len))
+
+  (define (offset/2 aspect)
+    (ash (- (aspect rotated)
+            edge-len)
+         -1))
+
+  (let ((src-rect (mkrect (offset/2 SDL:surface:w)
+                          (offset/2 SDL:surface:h)))
+        (dst      (create-square edge-len))
+        (dst-rect (mkrect 0 0)))
+    ((if (memq 'src-alpha (SDL:surface:flags rotated))
+         GFX:blit-rgba
+         SDL:blit-surface)
+     rotated src-rect dst dst-rect)
     dst))
 
 ;; Return a closure that manages a single rectangle object.
