@@ -1,6 +1,6 @@
 /* sdl.c --- SDL Wrappers for Guile
  *
- * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2021 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2021, 2022 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,7 +16,6 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <X11/Xlib.h>                   /* XInitThreads */
 #include "guile-sdl.h"
 
 struct obtw *btw;
@@ -184,11 +183,6 @@ static
 void
 init_module (void)
 {
-  /* Some versions of X are based on XCB, which is particular about
-     threads being initialized from a multi-threaded client.
-     This is the earliest we can do it.  */
-  XInitThreads ();
-
   /* Oh, by the way...  */
   btw = calloc (1, sizeof (*btw));
 
