@@ -1,6 +1,6 @@
 /* sdlgfx.c --- Additional Graphics functions for Guile SDL
  *
- * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015, 2022 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -914,18 +914,49 @@ or @code{#f} if unsuccessful.  */)
 }
 
 
+PRIMPROC
+(fps_manager_count, "fps-manager-count", 1, 0, 0,
+ (SCM mgr),
+ doc: /***********
+Return the frame count of FPS manager @var{mgr},
+or @code{#f} if unsuccessful.
+A frame is counted each time @code{fps-manager-delay!} is called.  */)
+{
+#define FUNC_NAME s_fps_manager_count
+  int ret;
+
+  ASSERT_FPSMGR (mgr, 1);
+
+  ret = SDL_getFramecount (UNPACK_FPSMGR (mgr));
+  return (0 > ret
+          ? SCM_BOOL_F
+          : NUM_INT (ret));
+#undef FUNC_NAME
+}
+
+
 PRIMPROC
 (fps_manager_delay_x, "fps-manager-delay!", 1, 0, 0,
  (SCM mgr),
  doc: /***********
-Request an appropriate delay from FPS manager @var{mgr}.  */)
+Request an appropriate delay from FPS manager @var{mgr}.
+For some versions of SDL_gfx (not the embedded one, currently),
+return the number of milliseconds elapsed since the last call.
+This value may be 0 (zero).  */)
 {
 #define FUNC_NAME s_fps_manager_delay_x
   ASSERT_FPSMGR (mgr, 1);
 
-  SDL_framerateDelay (UNPACK_FPSMGR (mgr));
+#if FPS_DELAY_RV_MEANINGFUL
 
+  return NUM_INT (SDL_framerateDelay (UNPACK_FPSMGR (mgr)));
+
+#else  /* !FPS_DELAY_RV_MEANINGFUL */
+
+  SDL_framerateDelay (UNPACK_FPSMGR (mgr));
   RETURN_UNSPECIFIED;
+
+#endif  /* !FPS_DELAY_RV_MEANINGFUL */
 #undef FUNC_NAME
 }
 
@@ -958,28 +989,63 @@ Otherwise, do nothing and return @code{#f}.  */)
 }
 
 
+PRIMPROC
+(multiply_pixel_alpha_x, "multiply-pixel-alpha!", 2, 0, 0,
+ (SCM surface, SCM factor),
+ doc: /***********
+Multiply the alpha channel of 32-bit @var{surface} by @var{factor},
+an integer 0-255, inclusive.  The result is scaled back; the effective
+factor is @var{factor}/256.  Return @code{#t} if alpha was changed.  */)
+{
+#define FUNC_NAME s_multiply_pixel_alpha_x
+  ASSERT_SURFACE (surface, 1);
+  ASSERT_INTEGER (factor, 2);
+
+  return (1 == SDL_gfxMultiplyAlpha (UNPACK_SURFACE (surface),
+                                     (Uint8) C_ULONG (factor))
+          ? SCM_BOOL_T
+          : SCM_BOOL_F);
+#undef FUNC_NAME
+}
+
+
 PRIMPROC
 (blit_rgba, "blit-rgba", 4, 0, 0,
  (SCM src, SCM srect, SCM dst, SCM drect),
  doc: /***********
 Blit from 32-bit surface @var{src} rectangle @var{srect}
 to 32-bit surface @var{dst} rectangle @var{drect}.
-Return @code{#t} if there are no problems.
+Return @code{#f} if there were problems (use @code{get-error}
+for more info); 1 if a blit was performed; 0 otherwise.
 
-Note that unlike @code{blit-surface} (@pxref{Video}),
-all arguments must be fully specified.  This restriction
-may be relaxed in the future.  */)
+Both @var{srect} and @var{drect} may be @code{#f} to
+indicate the entire surface as source or destination.  */)
 {
 #define FUNC_NAME s_blit_rgba
-  ASSERT_SURFACE (src, 1);
-  ASSERT_RECT (srect, 2);
-  ASSERT_SURFACE (dst, 3);
-  ASSERT_RECT (drect, 4);
+  SDL_Rect *csrect = NULL;
+  SDL_Rect *cdrect = NULL;
+  int ret;
 
-  RETURN_TRUE_IF_0 (SDL_gfxBlitRGBA (UNPACK_SURFACE (src),
-                                     UNPACK_RECT (srect),
-                                     UNPACK_SURFACE (dst),
-                                     UNPACK_RECT (drect)));
+  ASSERT_SURFACE (src, 1);
+  if (NOT_FALSEP (srect))
+    {
+      ASSERT_RECT (srect, 2);
+      csrect = UNPACK_RECT (srect);
+    }
+  ASSERT_SURFACE (dst, 3);
+  if (NOT_FALSEP (drect))
+    {
+      ASSERT_RECT (drect, 4);
+      cdrect = UNPACK_RECT (drect);
+    }
+
+  ret = SDL_gfxBlitRGBA (UNPACK_SURFACE (src),
+                         csrect,
+                         UNPACK_SURFACE (dst),
+                         cdrect);
+  return (0 > ret
+          ? SCM_BOOL_F
+          : NUM_INT (ret));
 #undef FUNC_NAME
 }
 
@@ -1241,7 +1307,7 @@ D = saturation255 (S + C).  */)
   unsigned int cc;
   SD_DECL_AND_CHECK ();
   ASSERT_NUMBER (c, 3);
-  cc = C_INT (c);
+  cc = C_ULONG (c);
   RETURN_TRUE_IF_0 (~0xffUL & cc
                     ? SDL_imageFilterAddUint (s, d, len, cc)
                     : SDL_imageFilterAddByte (s, d, len, cc));
@@ -1275,7 +1341,7 @@ D = saturation0 (S - C).  */)
   unsigned int cc;
   SD_DECL_AND_CHECK ();
   ASSERT_NUMBER (c, 3);
-  cc = C_INT (c);
+  cc = C_ULONG (c);
   RETURN_TRUE_IF_0 (~0xffUL & cc
                     ? SDL_imageFilterSubUint (s, d, len, cc)
                     : SDL_imageFilterSubByte (s, d, len, cc));
