@@ -1,6 +1,6 @@
 /* sdlsurface.c --- SDL Surface functions
  *
- * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015, 2021 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015, 2021, 2022 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -60,9 +60,12 @@ print_surface (SCM surface_smob, SCM port, UNUSED scm_print_state *pstate)
   char buf[80], sbuf[64];
 
   if (surface)
-    snprintf (sbuf, 64, "%dx%d %d bpp",
+    snprintf (sbuf, 64, "%dx%d %d bpp%s",
               surface->w, surface->h,
-              surface->format->BitsPerPixel);
+              surface->format->BitsPerPixel,
+              (surface->locked
+               ? " L"
+               : ""));
 
   snprintf (buf, 80, "#<%s %s>", surface_nick, surface ? sbuf : "NULL");
   scm_puts (buf, port);
@@ -614,7 +617,7 @@ Return pixel data of @var{surface} as a new uniform vector.
 The uvec has type @code{u8}, @code{u16} or @code{u32}, corresponding
 to the @var{surface} depth, with @var{height} x @var{width} elements.
 A 24bpp surface --- @var{depth-in-bytes} of 3 --- is expanded (per pixel)
-to @code{u32}, leaving the high nybble clear.
+to @code{u32}, leaving the high byte clear.
 
 Optional arg @var{squash} non-@code{#f} means to
 return a u8vector regardless of @var{surface} depth,
@@ -688,6 +691,20 @@ with @var{height} x @var{width} x @var{depth-in-bytes} elements.  */)
 }
 
 
+PRIMPROC
+(must_lock_p, "must-lock?", 1, 0, 0,
+ (SCM surface),
+ doc: /***********
+Return @code{#t} if @var{surface} needs to be locked before access.
+Failure to do so may result in a segfault.  */)
+{
+#define FUNC_NAME s_must_lock_p
+  ASSERT_SURFACE (surface, 1);
+  return BOOLEAN (SDL_MUSTLOCK (UNPACK_SURFACE (surface)));
+#undef FUNC_NAME
+}
+
+
 
 #include "k/alphalim.c"
 
