@@ -1,7 +1,7 @@
-/* level.h --- define ‘GI_LEVEL’ and ‘GI_LEVEL_1_8’
-   serial 2
+/* level.h --- define ‘GI_LEVEL’ et al
+   serial 4
 
-   Copyright (C) 2012, 2014 Thien-Thi Nguyen
+   Copyright (C) 2012, 2014, 2017, 2020 Thien-Thi Nguyen
 
    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,9 +14,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this package; see the file COPYING.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA  02110-1301  USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef SCM_MAJOR_VERSION
@@ -37,4 +35,10 @@
 
 #define GI_LEVEL_PRECISELY_1_8  (GI_LEVEL_1_8 && ! GI_LEVEL (1, 9))
 
+#define GI_LEVEL_2_0  GI_LEVEL (2, 0)
+
+#define GI_LEVEL_2_2  GI_LEVEL (2, 2)
+
+#define GI_LEVEL_3_0  GI_LEVEL (3, 0)
+
 /* level.h ends here */
