@@ -1,6 +1,6 @@
 ;;; image.scm --- simple image test
 
-;; Copyright (C) 2003, 2004, 2009, 2011, 2013 Thien-Thi Nguyen
+;; Copyright (C) 2003, 2004, 2009, 2011, 2013, 2015 Thien-Thi Nguyen
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -12,10 +12,8 @@
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 ;;
-;; You should have received a copy of the GNU General Public
-;; License along with this program; if not, write to the Free
-;; Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-;; Boston, MA  02110-1301  USA
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (use-modules ((sdl sdl) #:prefix SDL:))
 (use-modules ((sdl misc-utils) #:select (exact-truncate)))
@@ -115,7 +113,7 @@
   (try 16)
   (try 24)
   (try 32))
-(SDL:set-color-key! gnu-head #f 0) ; aka (SDL:surface-color-key! gnu-head #f)
+(SDL:surface-color-key! gnu-head #f)
 (standard-blit! gnu-head)
 
 ;; flip the double buffer
@@ -198,7 +196,6 @@
      (alpha 9 (+ 9 alpha)))
     ((= 9 i))
   (SDL:surface-alpha! gnu-head alpha)
-  (SDL:set-alpha! gnu-head 'src-alpha alpha)
   (standard-blit! gnu-head)
   (SDL:flip)
   (SDL:delay 20))
